//F1_FormatNamenAuflisten_503d.js
// 23.01.12 / Hans Haesler, Chtelard 52, CH-1018 Lausanne
//DESCRIPTION:Absatz- und Zeichenformatnamen auflisten

//Dieses Script setzt die Namen der Absatz- und der Zeichenformate 
//in zwei benannte Rahmen. Diese Listen knnen editiert werden (ganze 
//Zeilen entfernen). Dann das Script "FormatAttribute" starten, in den 
//Mens das Sternchen einstellen. Auf "OK" werden nur die Attribute der 
//Formate in der Liste ausgezogen und in ein neues Dokument eingesetzt.

//Wichtig: Wenn Formatgruppen vorhanden sind, dann mssen die Namen der 
//Gruppen erhalten bleiben. Es sei denn, die zugehrigen Formatnamen 
//wrden alle entfernt.
//Die Namen der Formate drfen nicht verndert werden. Das gilt auch 
//fr die drei Leerrume, welche vor jedem Namen eingefgt wurden.

// vorsichtshalber die Dialoge einschalten
app.scriptPreferences.userInteractionLevel = UserInteractionLevels.interactWithAll;

// prfen, ob ein Dokument geffnet ist
if (app.documents.length == 0) {
	alert ("Es ist kein Dokument offen.", "Achtung");
	exit();
}

// eine Referenz zum vordersten Dokument
var curDoc = app.documents[0];

// den Nullpunkt auf Null/Null setzen
curDoc.zeroPoint = [0,0];

// die Masseinheiten speichern
// wenn nicht 2053991795 (= Millimeter), auf Millimeter umstellen
vM = curDoc.viewPreferences.verticalMeasurementUnits;
hM = curDoc.viewPreferences.horizontalMeasurementUnits;
if (vM != 2053991795) {
	curDoc.viewPreferences.verticalMeasurementUnits = MeasurementUnits.millimeters;
}
if (hM != 2053991795) {
	curDoc.viewPreferences.horizontalMeasurementUnits = MeasurementUnits.millimeters;
}

// das Zeichenformat auf "Kein" setzen
var noCharStyle = curDoc.characterStyles.item(0);
curDoc.textDefaults.appliedCharacterStyle = noCharStyle;
// das Absatzformat auf "Einfacher Absatz" setzen
var dfParaStyle = curDoc.paragraphStyles.item(1);
curDoc.textDefaults.appliedParagraphStyle = dfParaStyle;

// eventuell vorhandene Rahmen entfernen. Sonst wrde ein Laufzeitfehler generiert, 
// weil das "FormatAttribute"-Script nur einen Rahmen jeder Sorte erwartet
try {
	curDoc.textFrames.itemByName("ParaStyles").remove();
}
catch (e) {
}

try {
	curDoc.textFrames.itemByName("CharStyles").remove();
}
catch (e) {
}

// prfen, ob Absatzformatgruppen bestehen
paraGroups = curDoc.paragraphStyleGroups;
var nPSG = paraGroups.length;

// prfen, ob Zeichenformatgruppen bestehen
charGroups = curDoc.characterStyleGroups;
var nCSG = charGroups.length;

//--- die Liste der Absatzformatnamen aufstellen ---//
if (nPSG == 0) {
	var allParaStyles = curDoc.paragraphStyles.everyItem().name;
	// das erste Element entfernen
	allParaStyles.shift();
}
else {
	var allParaStyles = curDoc.paragraphStyles.everyItem().name;
	// bei jedem Element drei Leerrume einfgen
	for (var i=0; i<allParaStyles.length; i++) {
		curName = "   " + allParaStyles[i];
		allParaStyles[i] = curName;
	}
	// das erste Element durch "[Root]" ersetzen
	allParaStyles[0] = "[Root]";
	// eine Schleife durch die Gruppen
	for (var i=0; i<nPSG; i++) {
		var curGroup = paraGroups[i];
		var curParaStyles = curGroup.paragraphStyles.everyItem().name;
		// bei jedem Element drei Leerrume einfgen
		for (var k=0; k<curParaStyles.length; k++) {
			curName = "   " + curParaStyles[k];
			curParaStyles[k] = curName;
		}
		// ein Element mit dem Namen der Gruppe voranstellen
		curParaStyles = [curGroup.name].concat(curParaStyles);
		allParaStyles = allParaStyles.concat(curParaStyles);
	}
}

// die Liste in eine Textkette verwandeln
var paraString = allParaStyles.join("\r");

// einen Textrahmen erzeugen
var paraFrame = curDoc.pages[0].textFrames.add();
paraFrame.properties = {geometricBounds:[12, 15, 285, 105.5], fillColor:"Paper", name:"ParaStyles"};

// die vorbereitete Textkette in den Rahmen einsetzen
paraFrame.parentStory.contents = paraString;

//--- die Liste der Zeichenformatnamen aufstellen ---//
if (nCSG == 0) {
	var allCharStyles = curDoc.characterStyles.everyItem().name;
	// das erste Element entfernen
	allCharStyles.shift();
}
else {
	var allCharStyles = curDoc.characterStyles.everyItem().name;
	// bei jedem Element drei Leerrume einfgen
	for (var i=0; i<allCharStyles.length; i++) {
		curName = "   " + allCharStyles[i];
		allCharStyles[i] = curName;
	}
	// das erste Element durch "[Root]" ersetzen
	allCharStyles[0] = "[Root]";
	// eine Schleife durch die Gruppen
	for (var i=0; i<nCSG; i++) {
		var curGroup = charGroups[i];
		var curCharStyles = curGroup.characterStyles.everyItem().name;
		// bei jedem Element drei Leerrume einfgen
		for (var k=0; k<curCharStyles.length; k++) {
			curName = "   " + curCharStyles[k];
			curCharStyles[k] = curName;
		}
		// ein Element mit dem Namen der Gruppe voranstellen
		curCharStyles = [curGroup.name].concat(curCharStyles);
		allCharStyles = allCharStyles.concat(curCharStyles);
	}
}

// die Liste in eine Textkette verwandeln
var charString = allCharStyles.join("\r");

// einen Textrahmen erzeugen
var charFrame = curDoc.pages[0].textFrames.add();
charFrame.properties = {geometricBounds:[12, 109.5, 285, 200], fillColor:"Paper", name:"CharStyles"};

// die vorbereitete Textkette in den Rahmen einsetzen
charFrame.parentStory.contents = charString;

if (vM != 2053991795) {
	curDoc.viewPreferences.verticalMeasurementUnits = vM;
}
if (hM != 2053991795) {
	curDoc.viewPreferences.horizontalMeasurementUnits = hM;
}